@@ -47,9 +47,9 @@
 #include <math.h>
 #include <KFormat>
 
-RSIObject::RSIObject( QWidget *parent )
-        : QObject( parent ), m_effect( 0 ),
-        m_useImages( false ), m_usePlasma( false ), m_usePlasmaRO( false )
+RSIObject::RSIObject( QWidget *parent ) : QObject( parent )
+        , m_timer(nullptr), m_effect( 0 )
+        , m_useImages( false ), m_usePlasma( false ), m_usePlasmaRO( false )
 {
     // Keep these 2 lines _above_ the messagebox, so the text actually is right.
     m_tray = new RSIDock( this );
@@ -80,6 +80,11 @@ RSIObject::~RSIObject()
 {
     delete m_effect;
     delete RSIGlobals::instance();
+    if (m_timer != nullptr) {
+        m_timer->quit();
+        m_timer->wait();
+        delete m_timer;
+    }
 }
 
 void RSIObject::slotWelcome()
@@ -107,7 +112,7 @@ void RSIObject::maximize()
 void RSIObject::slotLock()
 {
     m_effect->deactivate();
-    m_timer->slotRestart();
+    m_timer->slotLock();
 
     QDBusInterface lock( "org.freedesktop.ScreenSaver", "/ScreenSaver",
                          "org.freedesktop.ScreenSaver" );
@@ -169,34 +174,13 @@ void RSIObject::bigBreakSkipped()
 
 //--------------------------- CONFIG ----------------------------//
 
-void RSIObject::startTimer( bool idle )
+void RSIObject::configureTimer()
 {
-
-    static bool first = true;
-
-    if ( !first ) {
-        qDebug() << "Current Timer: " << m_timer->metaObject()->className()
-        << " wanted: " << ( idle ? "RSITimer" : "RSITimerNoIdle" ) << endl;
-
-        if ( !idle && !strcmp( m_timer->metaObject()->className(), "RSITimerNoIdle" ) )
-            return;
-
-        if ( idle && !strcmp( m_timer->metaObject()->className(), "RSITimer" ) )
-            return;
-
-        qDebug() << "Switching timers";
-
-        m_timer->exit();
-        m_timer->deleteLater();
-//        m_accel->remove("minimize");
+    if (m_timer != nullptr) {
+        m_timer->updateConfig();
+        return;
     }
-
-    if ( idle )
-        m_timer = new RSITimer( this );
-    else
-        m_timer = new RSITimerNoIdle( this );
-
-    m_timer->start();
+    m_timer = new RSITimer(this);
 
     connect(m_timer, &RSITimer::breakNow, this, &RSIObject::maximize, Qt::QueuedConnection );
     connect(m_timer, &RSITimer::updateWidget, this, &RSIObject::setCounters, Qt::QueuedConnection );
@@ -207,7 +191,7 @@ void RSIObject::startTimer( bool idle )
     connect(m_timer, &RSITimer::tinyBreakSkipped, this, &RSIObject::tinyBreakSkipped, Qt::QueuedConnection );
     connect(m_timer, &RSITimer::bigBreakSkipped, this, &RSIObject::bigBreakSkipped, Qt::QueuedConnection );
 
-    connect(m_tray, &RSIDock::configChanged, m_timer, &RSITimer::slotReadConfig);
+    connect(m_tray, &RSIDock::configChanged, m_timer, &RSITimer::updateConfig);
     connect(m_tray, &RSIDock::dialogEntered, m_timer, &RSITimer::slotStop);
     connect(m_tray, &RSIDock::dialogLeft, m_timer, &RSITimer::slotStart);
     connect(m_tray, &RSIDock::suspend, m_timer, &RSITimer::slotSuspended);
@@ -215,7 +199,7 @@ void RSIObject::startTimer( bool idle )
     connect(m_relaxpopup, &RSIRelaxPopup::skip, m_timer, &RSITimer::skipBreak);
     connect(m_relaxpopup, &RSIRelaxPopup::postpone, m_timer, &RSITimer::postponeBreak);
 
-    first = false;
+    m_timer->start();
 }
 
 void RSIObject::readConfig()
@@ -236,10 +220,10 @@ void RSIObject::readConfig()
     int slideInterval = config.readEntry( "SlideInterval", 10 );
     bool recursive =  config.readEntry( "SearchRecursiveCheck", false );
     bool showSmallImages = config.readEntry( "ShowSmallImagesCheck", true );
+    const bool expandImageToFullScreen = config.readEntry( "ExpandImageToFullScreen", true );
     QString path = config.readEntry( "ImageFolder" );
 
-    bool timertype = config.readEntry( "UseNoIdleTimer", false );
-    startTimer( !timertype );
+    configureTimer();
 
     int effect =  config.readEntry( "Effect", 0 );
 
@@ -252,7 +236,7 @@ void RSIObject::readConfig()
     }
     case SlideShow: {
         SlideEffect* slide = new SlideEffect( 0 );
-        slide->reset( path, recursive, showSmallImages, slideInterval );
+        slide->reset( path, recursive, showSmallImages, expandImageToFullScreen, slideInterval );
         if ( slide->hasImages() )
             m_effect = slide;
         else {
